@@ -2,7 +2,6 @@ OC.L10N.register(
     "deck",
     {
     "Deck" : "დასტა",
-    "Personal" : "პირადი",
     "The card \"%s\" on \"%s\" has reached its due date." : "ბარათმა \"%s\" \"%s\"-ზე მიაღწია დანიშნულ დროს.",
     "The board \"%s\" has been shared with you by %s." : "დაფა \"%s\" თქვენთან გაზიარდა %s-ისთვის.",
     "%s on %s" : "%s %s-ზე",
@@ -17,16 +16,17 @@ OC.L10N.register(
     "Missing a temporary folder" : "დროებითი დირექტორია არ არსებობს",
     "Invalid date, date format must be YYYY-MM-DD" : "არასწორი თარიღი, თარიღის ფორმატი უნდა იყოს წწწწ-თთ-დდ",
     "Cancel" : "უარყოფა",
-    "Close" : "დახურვა",
     "File already exists" : "ფაილი უკვე არსებობს",
     "Do you want to overwrite it?" : "გსურთ მისი გადაწერა?",
     "Add card" : "ბარათის დამატება",
     "Filter by tag" : "ფილტრი ტეგებით",
+    "Completed" : "დასრულებული",
     "Hide archived cards" : "არქივირებული ბარათების დამალვა",
     "Show archived cards" : "არქივირებული ბარათების ჩვენება",
     "Details" : "დეტალები",
     "Sharing" : "გაზიარება",
     "Tags" : "ტეგები",
+    "Activity" : "აქტივობა",
     "Undo" : "დაბრუნება",
     "Can edit" : "შეუძლია შეცვალოს",
     "Can share" : "შეუძლია გააზიაროს",
@@ -35,20 +35,22 @@ OC.L10N.register(
     "Edit" : "შეცვლა",
     "Members" : "წევრები",
     "Download" : "ჩამოტვირთვა",
-    "Comments" : "კომენტარები",
     "Modified" : "შეიცვალა",
     "Created" : "შექმნილია",
-    "Due date" : "დროისთვის",
-    "Remove due date" : "მოაშორეთ დანიშნულების დრო",
-    "Today" : "დღეს",
-    "Tomorrow" : "ხვალ",
+    "Comments" : "კომენტარები",
     "Save" : "შენახვა",
+    "Created:" : "შექმნილია:",
     "Reply" : "პასუხი",
     "Update" : "განახლება",
     "Description" : "აღწერა",
     "Formatting help" : "დახმარება ფორმატირებაზე",
+    "Remove due date" : "მოაშორეთ დანიშნულების დრო",
     "(group)" : "(ჯგუფი)",
     "seconds ago" : "წამის წინ",
+    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
+    "Keyboard shortcut" : "კლავიატურის კომბინაცია",
+    "Action" : "ქმედება",
+    "Search" : "ძიება",
     "Archived boards" : "არქივირებული დაფები",
     "Shared with you" : "გაზიარებული თქვენთან",
     "Board details" : "დაფის დეტალები",
@@ -57,7 +59,11 @@ OC.L10N.register(
     "Archive board" : "დაფის არქივირება",
     "No notifications" : "შეტყობინებები არაა",
     "Delete board" : "დაფის გაუქმება",
+    "Advanced options" : "დამატებითი ოპციონები",
+    "Today" : "დღეს",
+    "Tomorrow" : "ხვალ",
+    "Close" : "დახურვა",
     "Share" : "გაზიარება",
-    "This week" : "ამ კვირაში"
+    "Personal" : "პირადი"
 },
 "nplurals=2; plural=(n!=1);");
