@@ -1,12 +1,11 @@
 OC.L10N.register(
     "deck",
     {
-    "Personal" : "﻿ವೈಯಕ್ತಿಕ",
     "Done" : "Done",
     "No file was uploaded" : "ವರ್ಗಾವಣೆಗೆ ﻿ಯಾವುದೇ ಕಡತಗಳು ಕಂಡುಬಂದಿಲ್ಲ",
     "Missing a temporary folder" : "ತಾತ್ಕಾಲಿಕ ಕಡತಕೋಶ ದೊರೆಕುತ್ತಿಲ್ಲ",
     "Cancel" : "﻿ರದ್ದು",
-    "Close" : "ಮುಚ್ಚು",
+    "Open" : "ತೆರೆಯಿರಿ",
     "Sharing" : "﻿ಹಂಚಿಕೆ",
     "Can edit" : "Can edit",
     "Can share" : "Can share",
@@ -15,9 +14,12 @@ OC.L10N.register(
     "Edit" : "ಸಂಪಾದಿಸು",
     "Download" : "ಪ್ರತಿಯನ್ನು ಸ್ಥಳೀಯವಾಗಿ ಉಳಿಸಿಕೊಳ್ಳಿ",
     "Modified" : "﻿ಬದಲಾಯಿಸಿದ",
-    "Today" : "Today",
     "Save" : "﻿ಉಳಿಸಿ",
+    "Search" : "Search",
     "Shared with you" : "Shared with you",
-    "Share" : "﻿ಹಂಚಿಕೊಳ್ಳಿ"
+    "Today" : "Today",
+    "Close" : "ಮುಚ್ಚು",
+    "Share" : "﻿ಹಂಚಿಕೊಳ್ಳಿ",
+    "Personal" : "﻿ವೈಯಕ್ತಿಕ"
 },
 "nplurals=2; plural=(n > 1);");
