@@ -2,15 +2,12 @@ OC.L10N.register(
     "deck",
     {
     "Deck" : "Shto paisjen U2F",
-    "Personal" : "Personale",
     "%s on %s" : "%s në %s",
     "Finished" : "Përfunduar",
     "To review" : "Për rishikim",
     "Action needed" : "Nevoitet veprim",
     "Later" : "Më vonë",
     "copy" : "kopjo",
-    "To do" : "Për t'u bërë",
-    "Doing" : "Duke e bërë",
     "Done" : "Përfunduar",
     "The file was uploaded" : "Skedari u ngarkua",
     "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Kartela e ngarkuar tejkalon udhëzimin MAX_FILE_SIZE që qe përcaktuar te formulari HTML",
@@ -18,15 +15,17 @@ OC.L10N.register(
     "Missing a temporary folder" : "Mungon një dosje e përkohshme",
     "Invalid date, date format must be YYYY-MM-DD" : "Datë e pavlefshme, formati i datës duhet të jetë VVVV-MM-DD",
     "Cancel" : "Anullo",
-    "Close" : "Mbylleni",
     "File already exists" : "Skedari ekziston tashmë",
     "Do you want to overwrite it?" : "Doni ta rishkruani atë?",
     "Add card" : "Shto kartë",
+    "Completed" : "Të plotësuara",
     "Hide archived cards" : "Fsheh kartat e arkivuara ",
     "Show archived cards" : "Trego kartat e arkivuara",
+    "Open details" : "Hapni detajet",
     "Details" : "Detajet",
     "Sharing" : "Ndarje",
     "Tags" : "Etiketa",
+    "Activity" : "Aktiviteti",
     "Undo" : "Ktheje pas",
     "Can edit" : "Can edit",
     "Can share" : "Mund të ndaj",
@@ -35,23 +34,24 @@ OC.L10N.register(
     "Edit" : "Edito",
     "Members" : "Anëtar",
     "Download" : "Shkarko",
-    "Attachments" : "Bashkangjitjet",
-    "Comments" : "Komentet",
     "Modified" : "Modifikuar ",
     "Created" : "U krijua",
-    "Due date" : "Data e vendosur",
-    "Remove due date" : "Hiq datën e mbarimit",
-    "Select Date" : "Zgjidhni Datën",
-    "Today" : "Sot",
-    "Tomorrow" : "Nesër",
+    "Attachments" : "Bashkangjitjet",
+    "Comments" : "Komentet",
     "Save" : "Ruaj",
+    "Created:" : "Krijuar:",
     "Reply" : "Përgjigju",
     "Update" : "Përditëso",
     "Description" : "Përshkrim",
     "Formatting help" : "Ndihmë formatimi",
+    "Select Date" : "Zgjidhni Datën",
+    "Remove due date" : "Hiq datën e mbarimit",
     "(group)" : "(grup)",
-    "List is empty" : "Lista është bosh",
     "seconds ago" : "sekonda më parë",
+    "Keyboard shortcuts" : "Shkurtoret e tastierës",
+    "Keyboard shortcut" : "Shkurtore tastiere",
+    "Action" : "Veprim",
+    "Search" : "Kërko",
     "Archived boards" : "Borde të arkivuara",
     "Shared with you" : "E ndarë me ju",
     "Board details" : "Detajet e Tabeles ",
@@ -60,7 +60,13 @@ OC.L10N.register(
     "Archive board" : "Arkivo bordin",
     "No notifications" : "Asnjë njofim",
     "Delete board" : "Fshij bordin",
+    "Advanced options" : "Opsione të avancuara",
+    "Today" : "Sot",
+    "Tomorrow" : "Nesër",
+    "Close" : "Mbylleni",
     "Share" : "Shpërndaje",
-    "This week" : "Këtë javë"
+    "Personal" : "Personale",
+    "To do" : "Për t'u bërë",
+    "Doing" : "Duke e bërë"
 },
 "nplurals=2; plural=(n != 1);");
