@@ -1,58 +1,42 @@
 <?php
+
 /**
- * @copyright Copyright (c) 2018 Ryan Fletcher <ryan.fletcher@codepassion.ca>
- *
- * @copyright Copyright (c) 2019, Alexandru Puiu (alexpuiu20@yahoo.com)
- *
- * @author Ryan Fletcher <ryan.fletcher@codepassion.ca>
- *
- * @license GNU AGPL version 3 or any later version
- *
- *  This program is free software: you can redistribute it and/or modify
- *  it under the terms of the GNU Affero General Public License as
- *  published by the Free Software Foundation, either version 3 of the
- *  License, or (at your option) any later version.
- *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Affero General Public License for more details.
- *
- *  You should have received a copy of the GNU Affero General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
- namespace OCA\Deck\Controller;
+namespace OCA\Deck\Controller;
 
- use OCA\Deck\Service\AssignmentService;
- use OCP\AppFramework\ApiController;
- use OCP\AppFramework\Http;
- use OCP\AppFramework\Http\DataResponse;
- use OCP\IRequest;
- use OCA\Deck\Service\CardService;
+use OCA\Deck\Model\OptionalNullableValue;
+use OCA\Deck\Service\AssignmentService;
+use OCA\Deck\Service\CardService;
+use OCP\AppFramework\ApiController;
+use OCP\AppFramework\Http;
+use OCP\AppFramework\Http\DataResponse;
+use OCP\IRequest;
 
- /**
-  * Class BoardApiController
-  *
-  * @package OCA\Deck\Controller
-  */
+/**
+ * Class BoardApiController
+ *
+ * @package OCA\Deck\Controller
+ */
 class CardApiController extends ApiController {
-	private $cardService;
-	private $userId;
-	private $assignmentService;
 
 	/**
 	 * @param string $appName
 	 * @param IRequest $request
 	 * @param CardService $cardService
+	 * @param AssignmentService $assignmentService
 	 * @param $userId
 	 */
-	public function __construct($appName, IRequest $request, CardService $cardService, AssignmentService $assignmentService, $userId) {
+	public function __construct(
+		string $appName,
+		IRequest $request,
+		private CardService $cardService,
+		private AssignmentService $assignmentService,
+		private $userId,
+	) {
 		parent::__construct($appName, $request);
-		$this->cardService = $cardService;
-		$this->userId = $userId;
-		$this->assignmentService = $assignmentService;
 	}
 
 	/**
@@ -81,8 +65,17 @@ class CardApiController extends ApiController {
 	 *
 	 * Get a specific card.
 	 */
-	public function create($title, $type = 'plain', $order = 999, $description = '', $duedate = null) {
+	public function create($title, $type = 'plain', $order = 999, $description = '', $duedate = null, $labels = [], $users = []) {
 		$card = $this->cardService->create($title, $this->request->getParam('stackId'), $type, $order, $this->userId, $description, $duedate);
+
+		foreach ($labels as $labelId) {
+			$this->cardService->assignLabel($card->id, $labelId);
+		}
+
+		foreach ($users as $user) {
+			$this->assignmentService->assignUser($card->id, $user['id'], $user['type']);
+		}
+
 		return new DataResponse($card, HTTP::STATUS_OK);
 	}
 
@@ -95,7 +88,8 @@ class CardApiController extends ApiController {
 	 * Update a card
 	 */
 	public function update($title, $type, $owner, $description = '', $order = 0, $duedate = null, $archived = null) {
-		$card = $this->cardService->update($this->request->getParam('cardId'), $title, $this->request->getParam('stackId'), $type, $owner, $description, $order, $duedate, 0, $archived);
+		$done = array_key_exists('done', $this->request->getParams()) ? new OptionalNullableValue($this->request->getParam('done', null)) : null;
+		$card = $this->cardService->update($this->request->getParam('cardId'), $title, $this->request->getParam('stackId'), $type, $owner, $description, $order, $duedate, 0, $archived, $done);
 		return new DataResponse($card, HTTP::STATUS_OK);
 	}
 
@@ -159,6 +153,30 @@ class CardApiController extends ApiController {
 		return new DataResponse($card, HTTP::STATUS_OK);
 	}
 
+	/**
+	 * @NoAdminRequired
+	 * @CORS
+	 * @NoCSRFRequired
+	 *
+	 * Archive card
+	 */
+	public function archive($cardId) {
+		$card = $this->cardService->archive($cardId);
+		return new DataResponse($card, HTTP::STATUS_OK);
+	}
+
+	/**
+	 * @NoAdminRequired
+	 * @CORS
+	 * @NoCSRFRequired
+	 *
+	 * Unarchive card
+	 */
+	public function unarchive($cardId) {
+		$card = $this->cardService->unarchive($cardId);
+		return new DataResponse($card, HTTP::STATUS_OK);
+	}
+
 	/**
 	 * @NoAdminRequired
 	 * @CORS
